Crate spl_single_pool

Crate spl_single_pool 

A program for liquid staking with a single validator

Modules

error
Error types
inline_mpl_token_metadata
Inline MPL metadata types to avoid a direct dependency on `mpl-token-metadata’.
instruction
Instruction types
processor
program state processor
state
State transition types

Constants

DEPOSIT_SOL_FEE_BPS
Fee charged for the DepositSol instruction. This fee may be adjusted down in the future depending on how DepositSol is used in practice. Care should be taken if using this number for calculations in third-party libraries or programs, as it is not guaranteed to remain at this value.
ID
The const program ID.

Functions

check_id
Returns true if given address is the ID.
find_pool_address
Find the canonical pool address for a given vote account.
find_pool_mint_address
Find the canonical token mint address for a given pool account.
find_pool_mint_authority_address
Find the canonical mint authority address for a given pool account.
find_pool_mpl_authority_address
Find the canonical MPL authority address for a given pool account.
find_pool_onramp_address
Find the canonical stake on-ramp account address for a given pool account.
find_pool_stake_address
Find the canonical main stake account address for a given pool account.
find_pool_stake_authority_address
Find the canonical stake authority address for a given pool account.
id
Returns the ID.