#[repr(u32)]pub enum SinglePoolError {
Show 24 variants
InvalidPoolAccount = 0,
InvalidPoolStakeAccount = 1,
InvalidPoolMint = 2,
InvalidPoolStakeAuthority = 3,
InvalidPoolMintAuthority = 4,
InvalidPoolMplAuthority = 5,
InvalidMetadataAccount = 6,
InvalidMetadataSigner = 7,
DepositTooSmall = 8,
WithdrawalTooSmall = 9,
WithdrawalTooLarge = 10,
SignatureMissing = 11,
WrongStakeState = 12,
ArithmeticOverflow = 13,
UnexpectedMathError = 14,
LegacyVoteAccount = 15,
UnparseableVoteAccount = 16,
WrongRentAmount = 17,
InvalidPoolStakeAccountUsage = 18,
PoolAlreadyInitialized = 19,
InvalidPoolOnRampAccount = 20,
OnRampDoesntExist = 21,
ReplenishRequired = 22,
WithdrawalViolatesPoolRequirements = 23,
}Expand description
Errors that may be returned by the SinglePool program.
Variants
InvalidPoolAccount = 0
Provided pool account has the wrong address for its vote account, is uninitialized, or otherwise invalid.
InvalidPoolStakeAccount = 1
Provided pool stake account does not match address derived from the pool account.
InvalidPoolMint = 2
Provided pool mint does not match address derived from the pool account.
InvalidPoolStakeAuthority = 3
Provided pool stake authority does not match address derived from the pool account.
InvalidPoolMintAuthority = 4
Provided pool mint authority does not match address derived from the pool account.
InvalidPoolMplAuthority = 5
Provided pool MPL authority does not match address derived from the pool account.
InvalidMetadataAccount = 6
Provided metadata account does not match metadata account derived for pool mint.
InvalidMetadataSigner = 7
Authorized withdrawer provided for metadata update does not match the vote account.
DepositTooSmall = 8
Not enough lamports provided for deposit to result in one pool token.
WithdrawalTooSmall = 9
Not enough pool tokens provided to withdraw stake worth one lamport.
WithdrawalTooLarge = 10
Not enough stake to cover the provided quantity of pool tokens.
This typically means the value exists in the pool as activating stake,
and an epoch is required for it to become available. Otherwise, it means
active stake in the on-ramp must be moved via ReplenishPool.
SignatureMissing = 11
Required signature is missing.
WrongStakeState = 12
Stake account is not in the state expected by the program.
ArithmeticOverflow = 13
Unsigned subtraction crossed the zero.
UnexpectedMathError = 14
A calculation failed unexpectedly. (This error should never be surfaced; it stands in for failure conditions that should never be reached.)
LegacyVoteAccount = 15
The V0_23_5 vote account type is unsupported and should be upgraded via
convert_to_current().
UnparseableVoteAccount = 16
Failed to parse vote account.
WrongRentAmount = 17
Incorrect number of lamports provided for rent-exemption when initializing.
InvalidPoolStakeAccountUsage = 18
Attempted to deposit from or withdraw to pool stake account.
PoolAlreadyInitialized = 19
Attempted to initialize a pool that is already initialized.
InvalidPoolOnRampAccount = 20
Provided pool on-ramp account does not match address derived from the pool account.
OnRampDoesntExist = 21
The on-ramp account for this pool does not exist; you must call InitializePoolOnRamp
before you can perform this operation.
ReplenishRequired = 22
The present operation requires a ReplenishPool call, either because the pool stake account
is in an exceptional state, or because the on-ramp account should be refreshed.
WithdrawalViolatesPoolRequirements = 23
Withdrawal would render the pool stake account impossible to redelegate. This can only occur if the Stake Program minimum delegation increases above 1 sol.