A program for liquid staking with a single validator
Modules
- error
- Error types
- inline_
mpl_ token_ metadata - Inline MPL metadata types to avoid a direct dependency on `mpl-token-metadata’.
- instruction
- Instruction types
- processor
- program state processor
- state
- State transition types
Constants
- DEPOSIT_
SOL_ FEE_ BPS - Fee charged for the
DepositSolinstruction. This fee may be adjusted down in the future depending on howDepositSolis used in practice. Care should be taken if using this number for calculations in third-party libraries or programs, as it is not guaranteed to remain at this value. - ID
- The const program ID.
Functions
- check_
id - Returns
trueif given address is the ID. - find_
pool_ address - Find the canonical pool address for a given vote account.
- find_
pool_ mint_ address - Find the canonical token mint address for a given pool account.
- find_
pool_ mint_ authority_ address - Find the canonical mint authority address for a given pool account.
- find_
pool_ mpl_ authority_ address - Find the canonical MPL authority address for a given pool account.
- find_
pool_ onramp_ address - Find the canonical stake on-ramp account address for a given pool account.
- find_
pool_ stake_ address - Find the canonical main stake account address for a given pool account.
- find_
pool_ stake_ authority_ address - Find the canonical stake authority address for a given pool account.
- id
- Returns the ID.